@@ -40,19 +40,54 @@ mockVocabRef <- function(backend = "data_frame") {
 
   # compulsory tables
   person <- dplyr::tibble(
-    person_id = 1, gender_concept_id = 0, year_of_birth = 1990,
-    race_concept_id = 0, ethnicity_concept_id = 0
+    person_id = c(1L:400L), gender_concept_id = 0L, year_of_birth = 1990L,
+    race_concept_id = 0L, ethnicity_concept_id = 0L
   )
   observationPeriod <- dplyr::tibble(
-    observation_period_id = 1, person_id = 1,
+    observation_period_id = 1L, person_id = 1L,
     observation_period_start_date = as.Date("2000-01-01"),
-    observation_period_end_date = as.Date("2025-12-31"),
-    period_type_concept_id = 0
+    observation_period_end_date = as.Date("2024-12-31"),
+    period_type_concept_id = 0L
+  )
+
+  # condition accurrence table
+  conditionOccurrence <- rbind(
+    dplyr::tibble(
+      condition_occurrence_id = c(1L:400L),
+      condition_concept_id = 4L,
+      person_id = c(1L:400L),
+      condition_start_date = as.Date("2010-01-01"),
+      condition_end_date = as.Date("2010-01-01"),
+      condition_type_concept_id = NA_integer_,
+      condition_source_concept_id = NA_integer_,
+      condition_source_value = NA_character_
+    ),
+    dplyr::tibble(
+      condition_occurrence_id = c(201L:400L),
+      condition_concept_id = 5L,
+      person_id = c(1L:200L),
+      condition_start_date = as.Date("2010-01-01"),
+      condition_end_date = as.Date("2010-01-01"),
+      condition_type_concept_id = NA_integer_,
+      condition_source_concept_id = NA_integer_,
+      condition_source_value = NA_character_
+    ),
+    dplyr::tibble(
+      condition_occurrence_id = c(401L:500L),
+      condition_concept_id = 9L,
+      person_id = c(1L:100L),
+      condition_start_date = as.Date("2010-01-01"),
+      condition_end_date = as.Date("2010-01-01"),
+      condition_type_concept_id = NA_integer_,
+      condition_source_concept_id = NA_integer_,
+      condition_source_value = NA_character_
+    )
   )
 
   # vocab tables
   concept <- data.frame(
-    concept_id = c(1:21, 35604877L, 35604394L, 22:24),
+    concept_id = c(1:10, 46234469, 12:13, 44784844, 15:21 , 35604877L, 35604394L, 22:24, 25:26) |>
+      as.integer(),
     concept_name = c(
       "Musculoskeletal disorder",
       "Osteoarthrosis",
@@ -67,7 +102,7 @@ mockVocabRef <- function(backend = "data_frame") {
       "Injection",
       "ALIMENTARY TRACT AND METABOLISM",
       "Descendant drug",
-      "Injectable",
+      "Injectable Foam",
       "Diseases of the musculoskeletal system and connective tissue",
       "Arthropathies",
       "Arthritis",
@@ -79,11 +114,14 @@ mockVocabRef <- function(backend = "data_frame") {
       "Topical Liquefied Gas",
       "percent",
       "milligram",
-      "Other musculoskeletal disorder"
+      "Other musculoskeletal disorder",
+      "Brand 1",
+      "Brand 2"
     ),
     domain_id = c(rep("Condition", 8), "Observation", rep("Drug", 5),
                   rep("Condition", 4), rep("Drug",5), rep("Unit",2),
-                  "Condition"),
+                  "Condition",
+                  rep("Drug", 2)),
     vocabulary_id = c(
       rep("SNOMED", 6),
       rep("Read", 2),
@@ -93,7 +131,8 @@ mockVocabRef <- function(backend = "data_frame") {
       rep("ICD10",4),
       rep("RxNorm",5),
       rep("UCUM",2),
-      "SNOMED"
+      "SNOMED",
+      rep("RxNorm Extension",2)
     ),
     standard_concept = c(
       rep("S", 6),
@@ -104,7 +143,7 @@ mockVocabRef <- function(backend = "data_frame") {
       rep("S",3),
       rep(NA,2),
       rep("S",2),
-      NA
+      rep(NA,3)
     ),
     concept_class_id = c(
       rep("Clinical Finding", 6),
@@ -116,7 +155,8 @@ mockVocabRef <- function(backend = "data_frame") {
       rep("Clinical Drug Form",2),
       rep("Dose Form",2),
       rep("Unit",2),
-      "Clinical Finding"
+      "Clinical Finding",
+      rep("Brand Name",2)
     ),
     concept_code = "1234",
     valid_start_date = as.Date(NA),
@@ -128,80 +168,80 @@ mockVocabRef <- function(backend = "data_frame") {
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 1L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 3L,
       descendant_concept_id = 3L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 2L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 3L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 4L,
-      min_levels_of_separation = 2,
-      max_levels_of_separation = 2
+      min_levels_of_separation = 2L,
+      max_levels_of_separation = 2L
     ),
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 5L,
-      min_levels_of_separation = 2,
-      max_levels_of_separation = 2
+      min_levels_of_separation = 2L,
+      max_levels_of_separation = 2L
     ),
     data.frame(
       ancestor_concept_id = 3L,
       descendant_concept_id = 4L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 3L,
       descendant_concept_id = 5L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 10L,
       descendant_concept_id = 10L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 10L,
       descendant_concept_id = 13L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 12L,
       descendant_concept_id = 12L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 12L,
       descendant_concept_id = 13L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 19L,
       descendant_concept_id = 13L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     )
   )
 
@@ -230,7 +270,7 @@ mockVocabRef <- function(backend = "data_frame") {
     ),
     data.frame(
       concept_id_1 = 10L,
-      concept_id_2 = 11L,
+      concept_id_2 = 46234469L,
       relationship_id = "RxNorm has dose form"
     ),
     data.frame(
@@ -240,7 +280,7 @@ mockVocabRef <- function(backend = "data_frame") {
     ),
     data.frame(
       concept_id_1 = 13L,
-      concept_id_2 = 14L,
+      concept_id_2 = 44784844L,
       relationship_id = "RxNorm has dose form"
     ),
     data.frame(
@@ -277,6 +317,31 @@ mockVocabRef <- function(backend = "data_frame") {
       concept_id_1 = 1L,
       concept_id_2 = 24L,
       relationship_id = "Mapped from"
+    ),
+    data.frame(
+      concept_id_1 = 10L,
+      concept_id_2 = 25L,
+      relationship_id = "Has brand name"
+    ),
+    data.frame(
+      concept_id_1 = 20L,
+      concept_id_2 = 25L,
+      relationship_id = "Has brand name"
+    ),
+    data.frame(
+      concept_id_1 = 20L,
+      concept_id_2 = 26L,
+      relationship_id = "Has brand name"
+    ),
+    data.frame(
+      concept_id_1 = 13L,
+      concept_id_2 = 26L,
+      relationship_id = "Has brand name"
+    ),
+    data.frame(
+      concept_id_1 = 21L,
+      concept_id_2 = 26L,
+      relationship_id = "Has brand name"
     )
   ) |>
     dplyr::mutate(valid_start_date = as.Date(NA),
@@ -289,14 +354,14 @@ mockVocabRef <- function(backend = "data_frame") {
       vocabulary_name = "SNOMED",
       vocabulary_reference = "1",
       vocabulary_version = "1",
-      vocabulary_concept_id = 1
+      vocabulary_concept_id = 1L
     ),
     data.frame(
       vocabulary_id = "None",
       vocabulary_name = "OMOP Standardized Vocabularies",
       vocabulary_reference = "Omop generated",
       vocabulary_version = "v5.0 22-JUN-22",
-      vocabulary_concept_id = 44819096
+      vocabulary_concept_id = 44819096L
     )
   )
 
@@ -305,37 +370,37 @@ mockVocabRef <- function(backend = "data_frame") {
       drug_concept_id = 10L,
       ingredient_concept_id = 10L,
       amount_value = NA_real_,
-      amount_unit_concept_id = 8576,
+      amount_unit_concept_id = 8576L,
       numerator_value = 0.010,
-      numerator_unit_concept_id = 8576,
+      numerator_unit_concept_id = 8576L,
       denominator_value = 0.5,
-      denominator_unit_concept_id = 8587,
+      denominator_unit_concept_id = 8587L,
       box_size = NA_integer_,
       valid_start_date = as.Date(NA),
       valid_end_date = as.Date(NA)
     ),
     data.frame(
       drug_concept_id = 20L,
-      ingredient_concept_id = NA_real_,
+      ingredient_concept_id = NA_integer_,
       amount_value = NA_real_,
       amount_unit_concept_id = 22L,
       numerator_value = NA_real_,
-      numerator_unit_concept_id = NA_real_,
+      numerator_unit_concept_id = NA_integer_,
       denominator_value = 0.5,
-      denominator_unit_concept_id = NA_real_,
+      denominator_unit_concept_id = NA_integer_,
       box_size = NA_integer_,
       valid_start_date = as.Date(NA),
       valid_end_date = as.Date(NA)
     ),
     data.frame(
       drug_concept_id = 21L,
-      ingredient_concept_id = NA_real_,
+      ingredient_concept_id = NA_integer_,
       amount_value = NA_real_,
       amount_unit_concept_id = 23L,
       numerator_value = NA_real_,
-      numerator_unit_concept_id = NA_real_,
+      numerator_unit_concept_id = NA_integer_,
       denominator_value = 0.5,
-      denominator_unit_concept_id = NA_real_,
+      denominator_unit_concept_id = NA_integer_,
       box_size = NA_integer_,
       valid_start_date = as.Date(NA),
       valid_end_date = as.Date(NA)
@@ -357,56 +422,21 @@ mockVocabRef <- function(backend = "data_frame") {
     )
   )
 
-  # achilles tables
-  # count of 400 records for knee osteoarthritis
-  # count of 200 records for hip osteoarthritis
-  achillesAnalysis <- dplyr::tibble(analysis_id = 1,
-                                    analysis_name = "1",
-                                    stratum_1_name = NA_character_,
-                                    stratum_2_name = NA_character_,
-                                    stratum_3_name = NA_character_,
-                                    stratum_4_name = NA_character_,
-                                    stratum_5_name = NA_character_,
-                                    is_default = NA,
-                                    category = NA_character_)
-  achillesResults <- dplyr::tibble(analysis_id = c(401, 401, 401),
-                                   stratum_1 = c("4", "5", "9"),
-                                   stratum_2 = NA_character_,
-                                   stratum_3 = NA_character_,
-                                   stratum_4 = NA_character_,
-                                   stratum_5 = NA_character_,
-                                   count_value = c(400, 200, 100))
-  achillesResultsDist <- dplyr::tibble(analysis_id = 1,
-                                       stratum_1 = NA_character_,
-                                       stratum_2 = NA_character_,
-                                       stratum_3 = NA_character_,
-                                       stratum_4 = NA_character_,
-                                       stratum_5 = NA_character_,
-                                       min_value = NA_integer_,
-                                       max_value = NA_integer_,
-                                       avg_value = NA_real_,
-                                       stdev_value = NA_real_,
-                                       median_value = NA_real_,
-                                       p10_value = NA_real_,
-                                       p25_value = NA_real_,
-                                       p75_value = NA_real_,
-                                       p90_value = NA_real_,
-                                       count_value = 5)
-
   cdm_df <- omopgenerics::cdmFromTables(tables = list(person = person,
                                                       concept = concept,
+                                                      condition_occurrence = conditionOccurrence,
                                                       concept_ancestor = conceptAncestor,
                                                       concept_synonym = conceptSynonym,
                                                       concept_relationship = conceptRelationship,
                                                       vocabulary = vocabulary,
                                                       drug_strength = drugStrength,
                                                       observation_period = observationPeriod,
-                                                      cdm_source = cdmSource,
-                                                      achilles_analysis = achillesAnalysis,
-                                                      achilles_results = achillesResults,
-                                                      achilles_results_dist = achillesResultsDist),
+                                                      cdm_source = cdmSource),
                                         cdmName = "mock")
 
+  cdm_df <- buildAchillesTables(cdm_df) |>
+    suppressMessages()
+
   if (backend == "data_frame") {
     return(cdm_df)
   }
