@@ -1,19 +1,19 @@
 test_that("getATCCodes working", {
-
+  skip_on_cran()
   backends <- c("database", "data_frame")
   for (i in seq_along(backends)) {
     cdm <- mockVocabRef(backend = backends[i])
 
     atcCodes <- getATCCodes(cdm, level = "ATC 1st")
     expect_true("codelist" %in% class(atcCodes))
-    expect_true(all(atcCodes[[1]] == c(12,13)))
+    expect_true(all(atcCodes[[1]] == c(12L, 13L)))
     expect_true(c("1234_alimentary_tract_and_metabolism") %in%
                   names(atcCodes))
     expect_true(inherits(atcCodes, "codelist"))
 
     atcCodes2 <- getATCCodes(cdm, level = "ATC 1st",
                              name = "ALIMENTARY TRACT AND METABOLISM")
-    expect_true(all(atcCodes2[[1]] == c(12,13)))
+    expect_true(all(atcCodes2[[1]] == c(12L, 13L)))
 
     atcCodes3 <- getATCCodes(cdm, level = "ATC 1st",
                              name = "ALIMENTARY TRACT AND METABOLISM",
@@ -26,7 +26,7 @@ test_that("getATCCodes working", {
                              name = "ALIMENTARY TRACT AND METABOLISM",
                              nameStyle = "{concept_id}_{concept_name}")
     expect_identical(names(atcCodes3), "12_alimentary_tract_and_metabolism")
-    expect_true(all(atcCodes3[[1]] == c(12,13)))
+    expect_true(all(atcCodes3[[1]] == c(12L, 13L)))
 
     if (backends[[i]] == "database") {
       CDMConnector::cdmDisconnect(cdm)
@@ -35,7 +35,7 @@ test_that("getATCCodes working", {
 })
 
 test_that("getATCCodes expected errors", {
-
+  skip_on_cran()
   backends <- c("database", "data_frame")
   for (i in seq_along(backends)) {
     cdm <- mockVocabRef(backend = backends[i])
@@ -52,37 +52,37 @@ test_that("getATCCodes expected errors", {
 })
 
 test_that("getDrugIngredientCodes working", {
-
+  skip_on_cran()
   backends <- c("database", "data_frame")
   for (i in seq_along(backends)) {
     cdm <- mockVocabRef(backend = backends[i])
 
     ing_codes0 <- getDrugIngredientCodes(cdm, nameStyle = "{concept_code}_{concept_name}")
-    expect_true(all(ing_codes0[[1]] == c(10,13)))
+    expect_true(all(ing_codes0[[1]] == c(10L, 13L)))
     expect_true(inherits(ing_codes0, "codelist"))
     expect_identical(names(ing_codes0),  c("1234_adalimumab", "1234_other_ingredient"))
 
     ing_codes1 <- getDrugIngredientCodes(cdm, nameStyle = "{concept_id}_{concept_name}")
-    expect_true(all(ing_codes1[[1]] == c(10,13)))
+    expect_true(all(ing_codes1[[1]] == c(10L, 13L)))
     expect_identical(names(ing_codes1),  c("10_adalimumab", "19_other_ingredient"))
 
     ing_codes2 <- getDrugIngredientCodes(cdm, name = "Adalimumab")
-    expect_true(all(ing_codes2[[1]] == c(10,13)))
+    expect_true(all(ing_codes2[[1]] == c(10L, 13L)))
     expect_true(names(ing_codes2) == "1234_adalimumab")
 
     ing_codes2 <- getDrugIngredientCodes(cdm, name = 10)
-    expect_true(all(ing_codes2[[1]] == c(10,13)))
+    expect_true(all(ing_codes2[[1]] == c(10L, 13L)))
     expect_true(names(ing_codes2) == "1234_adalimumab")
 
     ing_codes3 <- getDrugIngredientCodes(cdm,
                                          name = "Adalimumab",
-                                         doseForm = "injectable")
-    expect_true(all(ing_codes3[[1]] == c(13)))
+                                         doseForm = "injectable foam")
+    expect_true(all(ing_codes3[[1]] == c(13L)))
 
     ing_codes4 <- getDrugIngredientCodes(cdm,
                                          name = "Adalimumab",
                                          doseForm = "injection")
-    expect_true(all(ing_codes4[[1]] == c(10)))
+    expect_true(all(ing_codes4[[1]] == c(10L)))
 
     ing_codes5 <- getDrugIngredientCodes(cdm,
                                          name = "Adalimumab",
@@ -93,20 +93,20 @@ test_that("getDrugIngredientCodes working", {
 
     # limiting on ingredients
     ing_codes_all <- getDrugIngredientCodes(cdm,
-                                            ingredientRange = c(1,Inf))
+                                            ingredientRange = c(1, Inf))
     ing_codes_mono <- getDrugIngredientCodes(cdm,
-                                             ingredientRange = c(1,1))
+                                             ingredientRange = c(1, 1))
     ing_codes_comb <- getDrugIngredientCodes(cdm,
-                                             ingredientRange = c(2,Inf))
+                                             ingredientRange = c(2, Inf))
 
     expect_equal(ing_codes_all, ing_codes0)
-    expect_true(all(c(10) %in% ing_codes_mono$`1234_adalimumab`))
+    expect_true(all(c(10L) %in% ing_codes_mono$`1234_adalimumab`))
     expect_null(ing_codes_mono$`1234_other_ingredient`)
-    expect_true(all(c(13) %in% ing_codes_comb$`1234_adalimumab`))
-    expect_true(all(c(13) %in% ing_codes_comb$`1234_other_ingredient`))
+    expect_true(all(c(13L) %in% ing_codes_comb$`1234_adalimumab`))
+    expect_true(all(c(13L) %in% ing_codes_comb$`1234_other_ingredient`))
 
     expect_error(getDrugIngredientCodes(cdm,
-                                        ingredientRange = c(3,2)))
+                                        ingredientRange = c(3, 2)))
     expect_error(getDrugIngredientCodes(cdm,
                                         ingredientRange = c(3)))
     expect_error(getDrugIngredientCodes(cdm,
@@ -115,42 +115,90 @@ test_that("getDrugIngredientCodes working", {
                                         ingredientRange = c(-1, 25)))
 
 
-    if (backends[[i]] == "database") {
-      CDMConnector::cdmDisconnect(cdm)
-    }
+    expect_warning(empty_res_1 <- getDrugIngredientCodes(cdm,
+                                                         name = "not_a_drug_name",
+                                                         type = "codelist"))
+    expect_no_error(omopgenerics::newCodelist(empty_res_1))
+    expect_warning(empty_res_2 <- getDrugIngredientCodes(cdm,
+                                                         name = "not_a_drug_name",
+                                                         type = "codelist_with_details"))
+    expect_no_error(omopgenerics::newCodelistWithDetails(empty_res_2))
 
-  }
-})
+    expect_warning(getDrugIngredientCodes(cdm,
+                                          name = c("Adalimumab", "not_a_drug_name")))
+    expect_warning(getDrugIngredientCodes(cdm,
+                                          name = c("Adalimumab",
+                                                   "xxxxx",
+                                                   "zzzzz")))
 
-test_that("getDrugIngredientCodes expected errors", {
+    # simple concept expression
+    expect_true(nrow(getDrugIngredientCodes(cdm,
+                                            name = "adalimumab",
+                                            type = "concept_set_expression")[[1]]) == 1)
 
-  backends <- c("database","data_frame")
-  for (i in seq_along(backends)) {
-    cdm <- mockVocabRef(backend = backends[i])
-    expect_error(getDrugIngredientCodes(cdm, name = "Not an Ingredient"))
-    expect_error(getDrugIngredientCodes(cdm, name = -99))
+    # by adding criteria, we will now have specified codes
+    expect_true(nrow(getDrugIngredientCodes(cdm,
+                                            name = "adalimumab",
+                                            type = "concept_set_expression",
+                                            ingredientRange = c(1,4))[[1]]) == 2)
+    expect_true(getDrugIngredientCodes(cdm,
+                                       name = "adalimumab",
+                                       type = "concept_set_expression",
+                                       ingredientRange = c(1, 1))[[1]] |>
+                  dplyr::pull("concept_id") == 10L)
+    expect_true(getDrugIngredientCodes(cdm,
+                                       name = "adalimumab",
+                                       type = "concept_set_expression",
+                                       ingredientRange = c(2, 2))[[1]] |>
+                  dplyr::pull("concept_id") == 13L)
+    expect_warning(
+      expect_warning(
+      # no concepts with 3 ingredients
+      getDrugIngredientCodes(cdm,
+                             name = "adalimumab",
+                             type = "concept_set_expression",
+                             ingredientRange = c(3, 3))
+      )
+    )
+
+    # options not yet supported for concept set expression
+    expect_error(getDrugIngredientCodes(cdm,
+                                        name = "adalimumab",
+                                        type = "concept_set_expression",
+                                        doseUnit = c("mm")))
+    expect_error(getDrugIngredientCodes(cdm,
+                                        name = "adalimumab",
+                                        type = "concept_set_expression",
+                                        doseForm = "zzz"))
+    expect_error(getDrugIngredientCodes(cdm,
+                                        name = "adalimumab",
+                                        type = "concept_set_expression",
+                                        routeCategory = "xxx"))
 
     if (backends[[i]] == "database") {
       CDMConnector::cdmDisconnect(cdm)
     }
   }
-
 })
 
 test_that("no duplicate names example 1",{
   skip_on_cran()
   person <- dplyr::tibble(
-    person_id = 1, gender_concept_id = 0, year_of_birth = 1990,
-    race_concept_id = 0, ethnicity_concept_id = 0
+    person_id = 1L,
+    gender_concept_id = 0L,
+    year_of_birth = 1990L,
+    race_concept_id = 0L,
+    ethnicity_concept_id = 0L
   )
   observationPeriod <- dplyr::tibble(
-    observation_period_id = 1, person_id = 1,
+    observation_period_id = 1L,
+    person_id = 1L,
     observation_period_start_date = as.Date("2000-01-01"),
-    observation_period_end_date = as.Date("2025-12-31"),
-    period_type_concept_id = 0
+    observation_period_end_date = as.Date("2024-12-31"),
+    period_type_concept_id = 0L
   )
   concept <- data.frame(
-    concept_id = 1:19,
+    concept_id = 1:19L,
     concept_name = c(
       "Musculoskeletal disorder",
       "Osteoarthrosis",
@@ -197,89 +245,88 @@ test_that("no duplicate names example 1",{
       "ICD Code","ICD Code", "Ingredient"
     ),
     concept_code = as.character(c(2:20)),
-    valid_start_date = NA,
-    valid_end_date = NA,
-    invalid_reason =
-      NA
+    valid_start_date = as.Date(NA),
+    valid_end_date = as.Date(NA),
+    invalid_reason = NA_character_
   )
   conceptAncestor <- dplyr::bind_rows(
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 1L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 3L,
       descendant_concept_id = 3L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 2L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 3L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 4L,
-      min_levels_of_separation = 2,
-      max_levels_of_separation = 2
+      min_levels_of_separation = 2L,
+      max_levels_of_separation = 2L
     ),
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 5L,
-      min_levels_of_separation = 2,
-      max_levels_of_separation = 2
+      min_levels_of_separation = 2L,
+      max_levels_of_separation = 2L
     ),
     data.frame(
       ancestor_concept_id = 3L,
       descendant_concept_id = 4L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 3L,
       descendant_concept_id = 5L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 10L,
       descendant_concept_id = 10L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 10L,
       descendant_concept_id = 13L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 12L,
       descendant_concept_id = 12L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 12L,
       descendant_concept_id = 13L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 19L,
       descendant_concept_id = 13L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     )
   )
   conceptSynonym <- dplyr::bind_rows(
@@ -292,7 +339,7 @@ test_that("no duplicate names example 1",{
       concept_synonym_name = "Osteoarthrosis"
     )
   )|>
-    dplyr::mutate(language_concept_id  = NA)
+    dplyr::mutate(language_concept_id  = NA_integer_)
 
   vocabulary <- dplyr::bind_rows(
     data.frame(
@@ -300,14 +347,14 @@ test_that("no duplicate names example 1",{
       vocabulary_name = "SNOMED",
       vocabulary_reference = "1",
       vocabulary_version = "1",
-      vocabulary_concept_id = 1
+      vocabulary_concept_id = 1L
     ),
     data.frame(
       vocabulary_id = "None",
       vocabulary_name = "OMOP Standardized Vocabularies",
       vocabulary_reference = "Omop generated",
       vocabulary_version = "v5.0 22-JUN-22",
-      vocabulary_concept_id = 44819096
+      vocabulary_concept_id = 44819096L
     )
   )
 
@@ -315,30 +362,30 @@ test_that("no duplicate names example 1",{
     data.frame(
       drug_concept_id = 10L,
       ingredient_concept_id = 10L,
-      amount_value = NA,
-      amount_unit_concept_id = 8576,
+      amount_value = NA_real_,
+      amount_unit_concept_id = 8576L,
       numerator_value = 0.010,
-      numerator_unit_concept_id = 8576,
+      numerator_unit_concept_id = 8576L,
       denominator_value = 0.5,
-      denominator_unit_concept_id = 8587,
-      box_size = NA,
-      valid_start_date = NA,
-      valid_end_date = NA
+      denominator_unit_concept_id = 8587L,
+      box_size = NA_integer_,
+      valid_start_date = as.Date(NA),
+      valid_end_date = as.Date(NA)
     )
   )
 
   cdmSource <- dplyr::as_tibble(
     data.frame(
       cdm_source_name  = "mock",
-      cdm_source_abbreviation = NA,
-      cdm_holder = NA,
-      source_description = NA,
-      source_documentation_reference = NA,
-      cdm_etl_reference = NA,
-      source_release_date = NA,
-      cdm_release_date = NA,
+      cdm_source_abbreviation = NA_character_,
+      cdm_holder = NA_character_,
+      source_description = NA_character_,
+      source_documentation_reference = NA_character_,
+      cdm_etl_reference = NA_character_,
+      source_release_date = as.Date(NA),
+      cdm_release_date = as.Date(NA),
       cdm_version = "5.3",
-      vocabulary_version  = NA
+      vocabulary_version  = NA_character_
     )
   )
 
@@ -389,9 +436,9 @@ test_that("no duplicate names example 1",{
       relationship_id = "Maps to"
     )
   ) |>
-    dplyr::mutate(valid_start_date = NA,
-                  valid_end_date = NA,
-                  invalid_reason = NA)
+    dplyr::mutate(valid_start_date = as.Date(NA),
+                  valid_end_date = as.Date(NA),
+                  invalid_reason = NA_character_)
 
   cdm_df <- omopgenerics::cdmFromTables(tables = list(person = person,
                                                       concept = concept,
@@ -460,17 +507,17 @@ test_that("no duplicate names example 1",{
 test_that("no duplicate names example 2",{
   skip_on_cran()
   person <- dplyr::tibble(
-    person_id = 1, gender_concept_id = 0, year_of_birth = 1990,
-    race_concept_id = 0, ethnicity_concept_id = 0
+    person_id = 1L, gender_concept_id = 0L, year_of_birth = 1990L,
+    race_concept_id = 0L, ethnicity_concept_id = 0L
   )
   observationPeriod <- dplyr::tibble(
-    observation_period_id = 1, person_id = 1,
+    observation_period_id = 1L, person_id = 1L,
     observation_period_start_date = as.Date("2000-01-01"),
-    observation_period_end_date = as.Date("2025-12-31"),
-    period_type_concept_id = 0
+    observation_period_end_date = as.Date("2024-12-31"),
+    period_type_concept_id = 0L
   )
   concept <- data.frame(
-    concept_id = 1:19,
+    concept_id = 1:19L,
     concept_name = c(
       "Musculoskeletal disorder",
       "Osteoarthrosis",
@@ -517,89 +564,88 @@ test_that("no duplicate names example 2",{
       "ICD Code","ICD Code", "ATC 1st"
     ),
     concept_code = as.character(c(2:20)),
-    valid_start_date = NA,
-    valid_end_date = NA,
-    invalid_reason =
-      NA
+    valid_start_date = as.Date(NA),
+    valid_end_date = as.Date(NA),
+    invalid_reason = NA_character_
   )
   conceptAncestor <- dplyr::bind_rows(
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 1L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 3L,
       descendant_concept_id = 3L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 2L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 3L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 4L,
-      min_levels_of_separation = 2,
-      max_levels_of_separation = 2
+      min_levels_of_separation = 2L,
+      max_levels_of_separation = 2L
     ),
     data.frame(
       ancestor_concept_id = 1L,
       descendant_concept_id = 5L,
-      min_levels_of_separation = 2,
-      max_levels_of_separation = 2
+      min_levels_of_separation = 2L,
+      max_levels_of_separation = 2L
     ),
     data.frame(
       ancestor_concept_id = 3L,
       descendant_concept_id = 4L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 3L,
       descendant_concept_id = 5L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 10L,
       descendant_concept_id = 10L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 10L,
       descendant_concept_id = 13L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 12L,
       descendant_concept_id = 12L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 12L,
       descendant_concept_id = 13L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     ),
     data.frame(
       ancestor_concept_id = 19L,
       descendant_concept_id = 13L,
-      min_levels_of_separation = 1,
-      max_levels_of_separation = 1
+      min_levels_of_separation = 1L,
+      max_levels_of_separation = 1L
     )
   )
   conceptSynonym <- dplyr::bind_rows(
@@ -612,7 +658,7 @@ test_that("no duplicate names example 2",{
       concept_synonym_name = "Osteoarthrosis"
     )
   )|>
-    dplyr::mutate(language_concept_id  = NA)
+    dplyr::mutate(language_concept_id  = NA_integer_)
 
   conceptRelationship <- dplyr::bind_rows(
     data.frame(
@@ -661,9 +707,9 @@ test_that("no duplicate names example 2",{
       relationship_id = "Maps to"
     )
   ) |>
-    dplyr::mutate(valid_start_date = NA,
-                  valid_end_date = NA,
-                  invalid_reason = NA)
+    dplyr::mutate(valid_start_date = as.Date(NA),
+                  valid_end_date = as.Date(NA),
+                  invalid_reason = NA_character_)
 
   vocabulary <- dplyr::bind_rows(
     data.frame(
@@ -671,14 +717,14 @@ test_that("no duplicate names example 2",{
       vocabulary_name = "SNOMED",
       vocabulary_reference = "1",
       vocabulary_version = "1",
-      vocabulary_concept_id = 1
+      vocabulary_concept_id = 1L
     ),
     data.frame(
       vocabulary_id = "None",
       vocabulary_name = "OMOP Standardized Vocabularies",
       vocabulary_reference = "Omop generated",
       vocabulary_version = "v5.0 22-JUN-22",
-      vocabulary_concept_id = 44819096
+      vocabulary_concept_id = 44819096L
     )
   )
 
@@ -686,30 +732,30 @@ test_that("no duplicate names example 2",{
     data.frame(
       drug_concept_id = 10L,
       ingredient_concept_id = 10L,
-      amount_value = NA,
-      amount_unit_concept_id = 8576,
+      amount_value = NA_real_,
+      amount_unit_concept_id = 8576L,
       numerator_value = 0.010,
-      numerator_unit_concept_id = 8576,
+      numerator_unit_concept_id = 8576L,
       denominator_value = 0.5,
-      denominator_unit_concept_id = 8587,
-      box_size = NA,
-      valid_start_date = NA,
-      valid_end_date = NA
+      denominator_unit_concept_id = 8587L,
+      box_size = NA_integer_,
+      valid_start_date = as.Date(NA),
+      valid_end_date = as.Date(NA)
     )
   )
 
   cdmSource <- dplyr::as_tibble(
     data.frame(
       cdm_source_name  = "mock",
-      cdm_source_abbreviation = NA,
-      cdm_holder = NA,
-      source_description = NA,
-      source_documentation_reference = NA,
-      cdm_etl_reference = NA,
-      source_release_date = NA,
-      cdm_release_date = NA,
+      cdm_source_abbreviation = NA_character_,
+      cdm_holder = NA_character_,
+      source_description = NA_character_,
+      source_documentation_reference = NA_character_,
+      cdm_etl_reference = NA_character_,
+      source_release_date = as.Date(NA),
+      cdm_release_date = as.Date(NA),
       cdm_version = "5.3",
-      vocabulary_version  = NA
+      vocabulary_version  = NA_character_
     )
   )
 
