@@ -5,10 +5,11 @@ test_that("table code use expcted columns", {
   cdm <- CDMConnector::cdmFromCon(con, cdmSchema = "main", writeSchema = "main")
 
   acetiminophen <- c(1125315,  1127433, 40229134,
-                     40231925, 40162522, 19133768,  1127078)
-  poliovirus_vaccine <- c(40213160)
-  cs <- list(acetiminophen = acetiminophen,
-             poliovirus_vaccine = poliovirus_vaccine)
+                     40231925, 40162522, 19133768,  1127078) |>
+    as.integer()
+  poliovirus_vaccine <- c(40213160L)
+  cs <- omopgenerics::newCodelist(list(acetiminophen = acetiminophen,
+                                       poliovirus_vaccine = poliovirus_vaccine))
 
   # Code use
   results <- summariseCodeUse(cs,
@@ -20,32 +21,34 @@ test_that("table code use expcted columns", {
                                               c(66, 100)))
   expect_no_error(tableCodeUse(result = results))
   expect_no_error(tableCodeUse(result = results,
-               type = "gt",
-               header = c("cdm_name", "estimate_name"),
-               groupColumn = NULL,
-               hide = character(),
-               .options = list()))
+                               style = "darwin"))
   expect_no_error(tableCodeUse(result = results,
-               type = "tibble",
-               header = c("cdm_name", "estimate_name"),
-               groupColumn = NULL,
-               hide = "source_concept_id",
-               .options = list()))
+                               type = "gt",
+                               header = c("cdm_name", "estimate_name"),
+                               groupColumn = NULL,
+                               hide = character(),
+                               .options = list()))
   expect_no_error(tableCodeUse(result = results,
-               type = "flextable",
-               header = c("cdm_name", "estimate_name"),
-               groupColumn = "domain_id",
-               .options = list()))
+                               type = "tibble",
+                               header = c("cdm_name", "estimate_name"),
+                               groupColumn = NULL,
+                               hide = "source_concept_id",
+                               .options = list()))
+  expect_no_error(tableCodeUse(result = results,
+                               type = "flextable",
+                               header = c("cdm_name", "estimate_name"),
+                               groupColumn = "domain_id",
+                               .options = list()))
 
   # Cohort code use
-  pharyngitis <- c(4112343)
+  pharyngitis <- c(4112343L)
   cdm <- CDMConnector::generateConceptCohortSet(cdm = cdm,
                                                 conceptSet = list(pharyngitis = pharyngitis),
                                                 name = "pharyngitis",
                                                 end = "observation_period_end_date",
                                                 overwrite = TRUE)
 
-  results_cohort <- summariseCohortCodeUse(list(cs = 4134304),
+  results_cohort <- summariseCohortCodeUse(omopgenerics::newCodelist(list(cs = 4134304L)),
                                            cdm = cdm,
                                            cohortTable = "pharyngitis",
                                            timing = "any")
@@ -88,10 +91,11 @@ test_that("table code use output formats", {
   cdm <- CDMConnector::cdmFromCon(con, cdmSchema = "main", writeSchema = "main")
 
   acetiminophen <- c(1125315,  1127433, 40229134,
-                     40231925, 40162522, 19133768,  1127078)
-  poliovirus_vaccine <- c(40213160)
-  cs <- list(acetiminophen = acetiminophen,
-             poliovirus_vaccine = poliovirus_vaccine)
+                     40231925, 40162522, 19133768,  1127078) |>
+    as.integer()
+  poliovirus_vaccine <- c(40213160L)
+  cs <- omopgenerics::newCodelist(list(acetiminophen = acetiminophen,
+                                       poliovirus_vaccine = poliovirus_vaccine))
 
   results <- summariseCodeUse(cs,
                               cdm = cdm,
@@ -100,11 +104,12 @@ test_that("table code use output formats", {
                               ageGroup = list(c(0,17),
                                               c(18,65),
                                               c(66, 100)))
-  tableCodeUse(result = results,
-               type = "flextable",
-               header = c("cdm_name", "estimate_name"),
-               groupColumn = "codelist_name",
-               .options = list())
+  expect_no_error(tableCodeUse(result = results,
+                               type = "flextable",
+                               header = c("cdm_name", "estimate_name"),
+                               groupColumn = "codelist_name",
+                               style = "darwin",
+                               .options = list()))
 
 
 
